use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007005
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( examples lib script t xt ) );
__DATA__
Dave
Dist
Doherty
Etheridge
Fredric
Graham
Gruenauer
Karen
Kent
Knop
Marcel
Mike
Peter
Plugin
Portability
PortabilityTests
Randy
Rolsky
Stauner
Test
Vereshagin
Zilla
autarch
doherty
ether
github
haarg
hanekomu
irc
kentfredric
lib
marcel
mike
peter
randy
rwstauner
